Index: Source/core/page/animation/AnimationBase.cpp |
diff --git a/Source/core/page/animation/AnimationBase.cpp b/Source/core/page/animation/AnimationBase.cpp |
index 40b7483e7a68984ee4f74cbe7466fefbcea145de..03ca1364b98648787f64ab384f02f4954391b915 100644 |
--- a/Source/core/page/animation/AnimationBase.cpp |
+++ b/Source/core/page/animation/AnimationBase.cpp |
@@ -555,8 +555,9 @@ void AnimationBase::freezeAtTime(double t) |
else |
m_pauseTime = m_startTime + t - m_animation->delay(); |
- // It is possible that m_isAccelerated is true and m_object->isComposited() is false, because of style change. |
- if (m_object && m_object->isComposited() && isAccelerated()) |
+ // It is possible that m_isAccelerated is true and m_object->compositingState() is NotComposited, because of style change. |
+ // So, both conditions need to be checked. |
+ if (m_object && m_object->compositingState() == PaintsIntoOwnBacking && isAccelerated()) |
toRenderBoxModelObject(m_object)->suspendAnimations(m_pauseTime); |
} |